@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Module that provides various utility methods on the portal level."""
 
 from Acquisition import aq_inner
@@ -9,6 +8,7 @@ from plone.api.exc import CannotGetPortalError
 from plone.api.exc import InvalidParameterError
 from plone.api.validation import required_parameters
 from plone.app.layout.navigation.root import getNavigationRootObject
+from plone.registry.interfaces import IRegistry
 from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.utils import getToolByName
 from Products.statusmessages.interfaces import IStatusMessage
@@ -19,20 +19,9 @@ from zope.globalrequest import getRequest
 from zope.interface.interfaces import IInterface
 
 import datetime as dtime
-import pkg_resources
-import six
 
 
-logger = getLogger('plone.api.portal')
-
-try:
-    pkg_resources.get_distribution('plone.registry')
-    from plone.registry.interfaces import IRegistry
-except pkg_resources.DistributionNotFound:
-    logger.warning(
-        'plone.registry is not installed. get_registry_record and '
-        'set_registry_record will be unavailable.',
-    )
+logger = getLogger("plone.api.portal")
 
 try:
     from Products import PrintingMailHost
@@ -46,16 +35,14 @@ elif (
     and PrintingMailHost.ENABLED.lower() in PrintingMailHost.TRUISMS
 ):
     PRINTINGMAILHOST_ENABLED = True
-elif (
-    PrintingMailHost.ENABLED is None
-    and PrintingMailHost.DevelopmentMode is True
-):
+elif PrintingMailHost.ENABLED is None and PrintingMailHost.DevelopmentMode is True:
     PRINTINGMAILHOST_ENABLED = True
 else:
     # PrintingMailHost only patches in debug mode.
     # plone.api.env.debug_mode cannot be used here, because .env imports this
     # file
     from App.config import getConfiguration
+
     PRINTINGMAILHOST_ENABLED = getConfiguration().debug_mode
 
 MISSING = object()
@@ -69,9 +56,8 @@ def get():
 
     :returns: Plone portal object
     :rtype: Portal object
-    :Example: :ref:`portal_get_example`
+    :Example: :ref:`portal-get-example`
     """
-
     closest_site = getSite()
     if closest_site is not None:
         for potential_portal in closest_site.aq_chain:
@@ -79,13 +65,13 @@ def get():
                 return potential_portal
 
     raise CannotGetPortalError(
-        'Unable to get the portal object. More info on '
-        'http://docs.plone.org/develop/plone.api/docs/api/exceptions.html'
-        '#plone.api.exc.CannotGetPortalError',
+        "Unable to get the portal object. More info on "
+        "https://docs.plone.org/develop/plone.api/docs/api/exceptions.html"
+        "#plone.api.exc.CannotGetPortalError",
     )
 
 
-@required_parameters('context')
+@required_parameters("context")
 def get_navigation_root(context=None):
     """Get the navigation root object for the context.
 
@@ -96,13 +82,13 @@ def get_navigation_root(context=None):
     :type context: context object
     :returns: Navigation Root
     :rtype: Portal object
-    :Example: :ref:`portal_get_navigation_root_example`
+    :Example: :ref:`portal-get-navigation-root-example`
     """
     context = aq_inner(context)
     return getNavigationRootObject(context, get())
 
 
-@required_parameters('name')
+@required_parameters("name")
 def get_tool(name=None):
     """Get a portal tool in a simple way.
 
@@ -112,27 +98,26 @@ def get_tool(name=None):
     :raises:
         :class:`~plone.api.exc.MissingParameterError`,
         :class:`~plone.api.exc.InvalidParameterError`
-    :Example: :ref:`portal_get_tool_example`
+    :Example: :ref:`portal-get-tool-example`
     """
     try:
         return getToolByName(get(), name)
     except AttributeError:
-
         # get a list of all tools to display their names in the error msg
         portal = get()
         tools = []
         for id in portal.objectIds():
-            if id.startswith('portal_'):
+            if id.startswith("portal_"):
                 tools.append(id)
 
         raise InvalidParameterError(
             "Cannot find a tool with name '{name}'.\n"
-            'Available tools are:\n'
-            '{tools}'.format(name=name, tools='\n'.join(tools)),
+            "Available tools are:\n"
+            "{tools}".format(name=name, tools="\n".join(tools)),
         )
 
 
-@required_parameters('recipient', 'subject', 'body')
+@required_parameters("recipient", "subject", "body")
 def send_email(
     sender=None,
     recipient=None,
@@ -157,33 +142,26 @@ def send_email(
     :type body: boolean
     :raises:
         ValueError
-    :Example: :ref:`portal_send_email_example`
+    :Example: :ref:`portal-send-email-example`
     """
     portal = get()
 
     if not PRINTINGMAILHOST_ENABLED:
         from plone.api import content
+
         ctrlOverview = content.get_view(
             context=portal,
             request=portal.REQUEST,
-            name='overview-controlpanel',
+            name="overview-controlpanel",
         )
         if ctrlOverview.mailhost_warning():
-            raise ValueError('MailHost is not configured.')
+            raise ValueError("MailHost is not configured.")
 
-    try:
-        encoding = get_registry_record('plone.email_charset')
-    except InvalidParameterError:
-        encoding = portal.getProperty('email_charset', 'utf-8')
+    encoding = get_registry_record("plone.email_charset")
 
     if not sender:
-        try:
-            from_address = get_registry_record('plone.email_from_address')
-            from_name = get_registry_record('plone.email_from_name')
-        except InvalidParameterError:
-            # Before Plone 5.0b2 these were stored in portal_properties
-            from_address = portal.getProperty('email_from_address', '')
-            from_name = portal.getProperty('email_from_name', '')
+        from_address = get_registry_record("plone.email_from_address")
+        from_name = get_registry_record("plone.email_from_name")
         sender = formataddr((from_name, from_address))
         if parseaddr(sender)[1] != from_address:
             # formataddr probably got confused by special characters.
@@ -191,10 +169,10 @@ def send_email(
 
     # If the mail headers are not properly encoded we need to extract
     # them and let MailHost manage the encoding.
-    if isinstance(body, six.text_type):
+    if isinstance(body, str):
         body = body.encode(encoding)
 
-    host = get_tool('MailHost')
+    host = get_tool("MailHost")
     host.send(
         body,
         recipient,
@@ -205,7 +183,7 @@ def send_email(
     )
 
 
-@required_parameters('datetime')
+@required_parameters("datetime")
 def get_localized_time(datetime=None, long_format=False, time_only=False):
     """Display a date/time in a user-friendly way.
 
@@ -232,15 +210,15 @@ def get_localized_time(datetime=None, long_format=False, time_only=False):
     :rtype: string
     :raises:
         ValueError
-    :Example: :ref:`portal_get_localized_time_example`
+    :Example: :ref:`portal-get-localized-time-example`
     """
-    tool = get_tool(name='translation_service')
+    tool = get_tool(name="translation_service")
     request = getRequest()
 
     # isinstance won't work because of date -> datetime inheritance
     if type(datetime) is dtime.date:
         if time_only:
-            return ''
+            return ""
         datetime = dtime.datetime(datetime.year, datetime.month, datetime.day)
         long_format = False
 
@@ -248,13 +226,13 @@ def get_localized_time(datetime=None, long_format=False, time_only=False):
         datetime,
         long_format,
         time_only,
-        domain='plonelocales',
+        domain="plonelocales",
         request=request,
     )
 
 
-@required_parameters('message', 'request')
-def show_message(message=None, request=None, type='info'):
+@required_parameters("message")
+def show_message(message=None, request=None, type="info"):
     """Display a status message.
 
     :param message: [required] Message to show.
@@ -265,14 +243,16 @@ def show_message(message=None, request=None, type='info'):
     :type type: string
     :raises:
         ValueError
-    :Example: :ref:`portal_show_message_example`
+    :Example: :ref:`portal-show-message-example`
     """
+    if request is None:
+        request = getRequest()
     IStatusMessage(request).add(message, type=type)
 
 
-@required_parameters('name')
+@required_parameters("name")
 def get_registry_record(name=None, interface=None, default=MISSING):
-    """Get a record value from ``plone.app.registry``
+    """Get a record value from ``plone.app.registry``.
 
     :param name: [required] Name
     :type name: string
@@ -283,15 +263,14 @@ def get_registry_record(name=None, interface=None, default=MISSING):
     :type default: anything
     :returns: Registry record value
     :rtype: plone.app.registry registry record
-    :Example: :ref:`portal_get_registry_record_example`
+    :Example: :ref:`portal-get-registry-record-example`
     """
     if not isinstance(name, str):
-        raise InvalidParameterError(u"The 'name' parameter has to be a string")
+        raise InvalidParameterError("The 'name' parameter has to be a string")
 
     if interface is not None and not IInterface.providedBy(interface):
         raise InvalidParameterError(
-            u'The interface parameter has to derive from '
-            u'zope.interface.Interface',
+            "The interface parameter has to derive from " "zope.interface.Interface",
         )
 
     registry = getUtility(IRegistry)
@@ -300,7 +279,7 @@ def get_registry_record(name=None, interface=None, default=MISSING):
         records = registry.forInterface(interface, check=False)
         _marker = object()
         if getattr(records, name, _marker) != _marker:
-            return registry['{0}.{1}'.format(interface.__identifier__, name)]
+            return registry["{}.{}".format(interface.__identifier__, name)]
 
         if default is not MISSING:
             return default
@@ -309,12 +288,12 @@ def get_registry_record(name=None, interface=None, default=MISSING):
         records = [key for key in interface.names()]
         msg = (
             'Cannot find a record with name "{name}"'
-            ' on interface {identifier}.\n'
-            'Did you mean?\n'
-            '{records}'.format(
+            " on interface {identifier}.\n"
+            "Did you mean?\n"
+            "{records}".format(
                 name=name,
                 identifier=interface.__identifier__,
-                records='\n'.join(records),
+                records="\n".join(records),
             )
         )
         raise InvalidParameterError(msg)
@@ -327,22 +306,20 @@ def get_registry_record(name=None, interface=None, default=MISSING):
 
     # Show all records that 'look like' name.
     # We don't dump the whole list, because it 1500+ items.
-    msg = (
-        "Cannot find a record with name '{name}'".format(name=name)
-    )
+    msg = "Cannot find a record with name '{name}'".format(name=name)
     records = [key for key in registry.records.keys() if name in key]
     if records:
         msg = (
-            '{message}\n'
-            'Did you mean?:\n'
-            '{records}'.format(message=msg, records='\n'.join(records))
+            "{message}\n"
+            "Did you mean?:\n"
+            "{records}".format(message=msg, records="\n".join(records))
         )
     raise InvalidParameterError(msg)
 
 
-@required_parameters('name', 'value')
+@required_parameters("name", "value")
 def set_registry_record(name=None, value=None, interface=None):
-    """Set a record value in the ``plone.app.registry``
+    """Set a record value in the ``plone.app.registry``.
 
     :param name: [required] Name of the record
     :type name: string
@@ -351,15 +328,14 @@ def set_registry_record(name=None, value=None, interface=None):
     :param interface: interface whose attributes are plone.app.registry
         settings
     :type interface: zope.interface.Interface
-    :Example: :ref:`portal_set_registry_record_example`
+    :Example: :ref:`portal-set-registry-record-example`
     """
     if not isinstance(name, str):
-        raise InvalidParameterError(u"The parameter 'name' has to be a string")
+        raise InvalidParameterError("The parameter 'name' has to be a string")
 
     if interface is not None and not IInterface.providedBy(interface):
         raise InvalidParameterError(
-            u'The interface parameter has to derive from '
-            u'zope.interface.Interface',
+            "The interface parameter has to derive from " "zope.interface.Interface",
         )
 
     registry = getUtility(IRegistry)
@@ -369,17 +345,18 @@ def set_registry_record(name=None, value=None, interface=None):
         get_registry_record(name=name, interface=interface)
 
         from zope.schema._bootstrapinterfaces import WrongType
+
         try:
-            registry[interface.__identifier__ + '.' + name] = value
+            registry[interface.__identifier__ + "." + name] = value
         except WrongType:
-            field_type = [
-                field[1]
-                for field in interface.namesAndDescriptions()
-                if field[0] == 'field_one'
-            ][0]
+            field_type = None
+            for field in interface.namesAndDescriptions():
+                if field[0] == name:
+                    field_type = field[1]
+                    break
             raise InvalidParameterError(
-                u'The value parameter for the field {name} needs to be '
-                u'{of_class} instead of {of_type}'.format(
+                "The value parameter for the field {name} needs to be "
+                "{of_class} instead of {of_type}".format(
                     name=name,
                     of_class=str(field_type.__class__),
                     of_type=type(value),
@@ -387,7 +364,6 @@ def set_registry_record(name=None, value=None, interface=None):
             )
 
     elif isinstance(name, str):
-
         # confirm that the record exists before setting the value
         get_registry_record(name)
 
@@ -399,19 +375,13 @@ def get_default_language():
 
     :returns: language identifier
     :rtype: string
-    :Example: :ref:`portal_get_default_language_example`
+    :Example: :ref:`portal-get-default-language-example`
     """
-    try:
-        from Products.CMFPlone.interfaces import ILanguageSchema
-    except ImportError:
-        portal = get()
-        return portal.portal_properties.site_properties.getProperty(
-            'default_language', None,
-        )
-    else:
-        registry = getUtility(IRegistry)
-        settings = registry.forInterface(ILanguageSchema, prefix='plone')
-        return settings.default_language
+    from plone.i18n.interfaces import ILanguageSchema
+
+    registry = getUtility(IRegistry)
+    settings = registry.forInterface(ILanguageSchema, prefix="plone")
+    return settings.default_language
 
 
 def get_current_language(context=None):
@@ -421,15 +391,17 @@ def get_current_language(context=None):
     :type context: object
     :returns: language identifier
     :rtype: string
-    :Example: :ref:`portal_get_current_language_example`
+    :Example: :ref:`portal-get-current-language-example`
     """
     request = getRequest()
-    return request.get('LANGUAGE', None) or \
-        (context and aq_inner(context).Language()) \
+    return (
+        request.get("LANGUAGE", None)
+        or (context and aq_inner(context).Language())
         or get_default_language()
+    )
 
 
-def translate(msgid, domain='plone', lang=None):
+def translate(msgid, domain="plone", lang=None):
     """Translate a message into a given language.
 
     Default to current negotiated language if no target language specified.
@@ -441,16 +413,16 @@ def translate(msgid, domain='plone', lang=None):
     :param lang: target language
     :type lang: string
     :returns: translated message
-    :rtype: six.text_type
-    :Example: :ref:`portal_translate_example`
+    :rtype: str
+    :Example: :ref:`portal-translate-example`
     """
-    translation_service = get_tool('translation_service')
+    translation_service = get_tool("translation_service")
     query = {
-        'msgid': msgid,
-        'domain': domain,
-        'target_language': lang,
+        "msgid": msgid,
+        "domain": domain,
+        "target_language": lang,
     }
     if lang is None:
         # Pass the request, so zope.i18n.translate can negotiate the language.
-        query['context'] = getRequest()
+        query["context"] = getRequest()
     return translation_service.utranslate(**query)
